@@ -7,7 +7,7 @@
 #include <avr/io.h>
 #include "avr_compat.h"
 #include "timeout.h"
-static unsigned char sck_dur=2;
+static unsigned char sck_dur=1;
 
 // set the speed (used by PARAM_SCK_DURATION, page 31 in AVR068)
 // For a clock of 3.6864MHz this is:
@@ -24,36 +24,36 @@ unsigned char  spi_set_sck_duration(unsigned char dur)
         if (dur >= 3){
         	// 28KHz
         	cbi(SPSR,SPI2X);
-        	sbi(SPCR,SPR0);
         	sbi(SPCR,SPR1);
+        	sbi(SPCR,SPR0);
                 sck_dur=3;
         	return(sck_dur);
         }
         if (dur == 2){
         	// 57KHz
         	cbi(SPSR,SPI2X);
-        	sbi(SPCR,SPR0);
-        	cbi(SPCR,SPR1);
+        	sbi(SPCR,SPR1);
+        	cbi(SPCR,SPR0);
                 sck_dur=2;
         	return(sck_dur);
         }
         if (dur == 1){
         	// 230KHz
         	cbi(SPSR,SPI2X);
-        	cbi(SPCR,SPR0);
-        	sbi(SPCR,SPR1);
+        	cbi(SPCR,SPR1);
+        	sbi(SPCR,SPR0);
                 sck_dur=1;
         	return(sck_dur);
         }
         if (dur == 0){
-        // 921KHz
+                // 921KHz
                 cbi(SPSR,SPI2X);
                 cbi(SPCR,SPR0);
                 cbi(SPCR,SPR1);
                 sck_dur=0;
                 return(sck_dur);
         }
-        return(4); // we should never come here
+        return(2); // we should never come here
 }
 
 unsigned char spi_get_sck_duration(void)
@@ -63,26 +63,22 @@ unsigned char spi_get_sck_duration(void)
 
 void spi_init(void) 
 {
-        unsigned char ci;
-        sbi(DDRB,PB2); // pb2 as reset pin is output
-        cbi(PORTB,PB2); // reset = low = active
-        delay_ms(2);
         cbi(PORTB,PB3); // MOSI low
         cbi(PORTB,PB5); // SCK low
         //
         sbi(DDRB,PB3); // MOSI is output
         sbi(DDRB,PB5); // SCK is output
         cbi(DDRB,PB4); // MISO is input
-        /* Enable SPI, Master, set clock rate fck/16 */
-        SPCR = (1<<SPE)|(1<<MSTR)|(1<<SPR0);
         //
-        sbi(PORTB,PB2); // reset = high
-        // 200 micro sec:
-        for(ci=0;ci<200;ci++) asm("nop");
+        sbi(DDRB,PB2); // pb2 as reset pin is output
+        sbi(PORTB,PB2); // reset = high = not active
+        delay_ms(2);
+        /* Enable SPI, Master, set clock rate fck/64 */
+        SPCR = (1<<SPE)|(1<<MSTR)|(1<<SPR1);
+        //
         cbi(PORTB,PB2); // reset = low, stay active
         delay_ms(2);
-        // read from eeprom in later versions:
-        spi_set_sck_duration(2);
+        spi_set_sck_duration(sck_dur);
 }
 
 // send 8 bit, return received byte
@@ -117,6 +113,11 @@ void spi_disable(void)
         SPCR=0x00;     // SPI off
         sbi(PORTB,PB2);// reset = high, off
         cbi(DDRB,PB3); // MOSI high impedance, input
+        cbi(PORTB,PINB3);// pullup off
         cbi(DDRB,PB5); // SCK high impedance, input
+        cbi(PORTB,PINB5);// pullup off
+        //
+        cbi(DDRB,PINB2); // reset pin as input, high impedance
+        cbi(PORTB,PINB2);// pullup off
 }
 
